# {py:mod}`itkwasm.binary_file`

```{py:module} itkwasm.binary_file
```

```{autodoc2-docstring} itkwasm.binary_file
:allowtitles:
```

## Module Contents

### Classes

````{list-table}
:class: autosummary longtable
:align: left

* - {py:obj}`BinaryFile <itkwasm.binary_file.BinaryFile>`
  - ```{autodoc2-docstring} itkwasm.binary_file.BinaryFile
    :summary:
    ```
````

### API

`````{py:class} BinaryFile
:canonical: itkwasm.binary_file.BinaryFile

```{autodoc2-docstring} itkwasm.binary_file.BinaryFile
```

````{py:attribute} path
:canonical: itkwasm.binary_file.BinaryFile.path
:type: pathlib.PurePosixPath
:value: >
   None

```{autodoc2-docstring} itkwasm.binary_file.BinaryFile.path
```

````

`````
